documentationtools.GraphvizGroup
================================

.. abjad-lineage:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup

.. autoclass:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.append
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.children
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.depth
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.depthwise_inventory
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.extend
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.graph_order
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.improper_parentage
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.index
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.insert
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.leaves
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.name
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.nodes
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.parent
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.pop
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.proper_parentage
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.remove
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.root
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__contains__
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__copy__
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__deepcopy__
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__delitem__
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__eq__
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__format__
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__getitem__
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__hash__
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__iter__
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__len__
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__ne__
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__repr__
      ~abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__setitem__

Bases
-----

- :py:class:`datastructuretools.TreeContainer <abjad.tools.datastructuretools.TreeContainer.TreeContainer>`

- :py:class:`datastructuretools.TreeNode <abjad.tools.datastructuretools.TreeNode.TreeNode>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.children
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.depth
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.depthwise_inventory
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.graph_order
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.improper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.leaves
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.nodes
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.parent
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.proper_parentage
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.root
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.append
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.extend
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.index
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.insert
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.pop
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.remove
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__contains__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__copy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__deepcopy__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__delitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__format__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__getitem__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__hash__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__iter__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__len__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__repr__
   :noindex:

.. automethod:: abjad.tools.documentationtools.GraphvizGroup.GraphvizGroup.__setitem__
   :noindex:
